@@ -911,3 +911,18 @@ mcs_client_check_manager (Display     *display,
     }
     return TRUE;
 }
+
+/**
+ * mcs_client_set_callback_userdata:
+ * @client: An #McsClient.
+ * @cb_data: callback userdata to set
+ *
+ * Sets userdata to use for the watch and notify callbacks.
+ * This is required if you want to avoid the global variable for the mcs client instance.
+ *
+ **/
+void
+mcs_client_set_callback_userdata (McsClient *client, void *cb_data)
+{
+    client->cb_data = cb_data;
+}
